@@ -53,6 +53,20 @@ class MNAEquationStack:
     """
 
     def __init__(self, graph: UniqueEdgeMultiDiGraph, couplings: Iterable[List[Branch]], references: Set[Hashable] = frozenset()):
+        """
+        Create a new equation system for a circuit.
+
+        :param graph:
+            The circuit graph that stores the connectivity between branches.
+        :param couplings:
+            The coupled branches. Coupled branches will receive the same voltage-current-vector ("coupling-vector") so
+            they can describe mutual dynamics between themselves (e.g. for coupled inductors).
+        :param references:
+            Ground nodes to prefer.
+            Invalid or conflicting ground nodes are ignored or resolved automatically by picking the first eligible
+            node. If no ground nodes are specified or if ground nodes are missing for a connected subgraph where another
+            ground node is required, it is automatically selected.
+        """
         self._cache = SimpleNamespace()
         self._cache.equation_lambdified = None
         self._cache.jacobian_lambdified = None
@@ -146,6 +160,8 @@ class MNAEquationStack:
 
     def _expand_jacobi_vector(self, jacobi, coupled_branches: List[Union[VoltageBranch, CurrentBranch]]) -> np.ndarray:
         # Properly creates a Jacobian vector suiting the problem from a component-tailored Jacobian.
+        # Effectively increases dimension and inserts zeroes accordingly so the Jacobian's from different branches can
+        # be easily blended together.
 
         jacobi_vector = np.zeros(len(self))
 
@@ -173,6 +189,8 @@ class MNAEquationStack:
     def _create_coupled_v_i_vector(self,
                                    v_i: np.ndarray,
                                    coupled_branches: List[Union[VoltageBranch, CurrentBranch]]) -> np.ndarray:
+        # Creates the voltage-current-vector ("coupling-vector") for a set of coupled branches from a solution.
+
         vec = []
 
         for branch in coupled_branches:
@@ -243,7 +261,7 @@ class MNAEquationStack:
 
         return np.array(out_vector)
 
-    def get_voltage_between_nodes(self, solution: np.ndarray, source, target):
+    def get_voltage_between_nodes(self, solution: np.ndarray, source, target) -> float:
         """
         Returns the voltage between two nodes from a calculated solution.
 
@@ -267,15 +285,33 @@ class MNAEquationStack:
         """
         return self._reference_nodes.keys()
 
-    def get_node_voltage(self, solution: np.ndarray, node: Hashable):
+    def get_node_voltage(self, solution: np.ndarray, node: Hashable) -> float:
+        """
+        Returns the voltage (or potential) of a node from a given solution.
+
+        :param solution:
+            The solution to get the voltage from.
+        :param node:
+            The node.
+        :return:
+            The voltage/potential measured in Volts.
+        """
         return solution[self._nodes.index(node)]
 
-    def get_node_voltages(self, solution: np.ndarray):
+    def get_node_voltages(self, solution: np.ndarray) -> Dict[Hashable, float]:
+        """
+        Returns the voltages (or potentials) from all nodes.
+
+        :param solution:
+            The solution to get the voltages from.
+        :return:
+            A dictionary mapping nodes to their respective voltage/potential.
+        """
         vs = {node: self.get_node_voltage(solution, node) for node in self._nodes}
         vs.update({gnd_node: 0 for gnd_node in self._reference_nodes})
         return vs
 
-    def get_voltage(self, solution: np.ndarray, branch: CurrentBranch):
+    def get_voltage(self, solution: np.ndarray, branch: CurrentBranch) -> float:
         """
         Returns the voltage for a given current-branch from a calculated solution.
 
@@ -292,7 +328,7 @@ class MNAEquationStack:
         source, target = self._graph.get_nodes(branch)
         return self.get_voltage_between_nodes(solution, source, target)
 
-    def get_current(self, solution: np.ndarray, branch: VoltageBranch):
+    def get_current(self, solution: np.ndarray, branch: VoltageBranch) -> float:
         """
         Returns the current for a given voltage-branch from a calculated solution.
 
@@ -515,6 +551,12 @@ class MNAEquationStack:
         return np.array(jacobi_matrix)
 
     def lambdify_jacobian(self):
+        """
+        Creates an optimized version of `jacobian` by compiling a more efficient Python expression.
+
+        :return:
+            A callable object that behaves like `jacobian` but faster.
+        """
         if self._cache.jacobian_lambdified is not None:
             return self._cache.jacobian_lambdified
 
