@@ -577,12 +577,13 @@ class TransientEFMSimulation:
             The interpolation time steps measured in seconds and interpolated states.
         """
         with self._modification_lock:
-            for state in self.get_interval_states(component):
-                return self._interpolate_intervals(
-                    self.get_interval_timesteps(),
-                    state,
-                    self._skips,
-                )
+            ts = np.zeros(0)
+            interpolations = []
+            for states in zip(*(list(zip(*interval)) for interval in self.get_interval_states(component))):
+                ts, interpolated = self._interpolate_intervals(self.get_interval_timesteps(), states, self._skips)
+                interpolations.append(interpolated)
+
+            return ts, np.transpose(interpolations)
 
     s = get_states  # Shorthand function
 
@@ -627,6 +628,8 @@ class TransientEFMSimulation:
             * v: voltage plot
             * i: current plot
             * p: power plot
+            * s: component states
+            * c: *c*ontrolled switch states
         :param throw:
             Whether exceptions from the computation thread are thrown in the calling thread.
             Set it to `False` if you also want to print partial results.
@@ -634,6 +637,16 @@ class TransientEFMSimulation:
         if not features:
             raise ValueError('no features specified')
 
+        component_features = {}
+        branch_features = {}
+        for i, feature in enumerate(features, start=1):
+            if feature == 'v' or feature == 'i' or feature == 'p' or feature == 'c':
+                branch_features[i] = feature
+            elif feature == 's':
+                component_features[i] = feature
+            else:
+                raise ValueError(f'invalid feature: {feature}')
+
         self.wait(throw=throw)
 
         # Determine necessary components and respective branches to plot.
@@ -666,9 +679,62 @@ class TransientEFMSimulation:
 
         for component, branches in plotset.items():
             color = next(colorcycle)
+
+            for i, feature in component_features.items():
+                # Currently there is only the "state"-feature, no need for an if-else.
+
+                intervals = list(zip(*(list(zip(*interval)) for interval in self.get_interval_states(component))))
+                envelopes = list(zip(*self.get_envelope_states(component)))
+                ts, interpolations = self.get_interpolated_states(component)
+                interpolations = np.transpose(interpolations)
+
+                for k in range(len(intervals)):
+                    fig.append_trace(
+                        Scatter(
+                            x=list(intersperse(self._tss, None)),
+                            y=list(intersperse(intervals[k], None)),
+                            legendgroup=f'state({str(component)})[{k}] (simulated)',
+                            name=f'state({component})[{k}] (simulated)',
+                            mode='lines',
+                            line={'color': color},
+                            showlegend=True,
+                        ),
+                        row=i,
+                        col=1,
+                    )
+
+                    fig.append_trace(
+                        Scatter(
+                            x=self.get_envelope_timesteps(),
+                            y=envelopes[k],
+                            legendgroup=f'state({str(component)})[{k}] (envelope)',
+                            name=f'state({component})[{k}] (envelope)',
+                            mode='lines',
+                            line={'color': color, 'dash': 'dash'},
+                            showlegend=True,
+                        ),
+                        row=i,
+                        col=1,
+                    )
+
+                    fig.append_trace(
+                        Scatter(
+                            x=ts,
+                            y=interpolations[k],
+                            legendgroup=f'state({str(component)})[{k}] (interpolated)',
+                            name=f'state({component})[{k}] (interpolated)',
+                            mode='lines',
+                            line={'color': color, 'dash': 'dot', 'width': 0.85},
+                            showlegend=True,
+                            visible='legendonly',
+                        ),
+                        row=i,
+                        col=1,
+                    )
+
             for branch in branches:
                 showlegend = True
-                for i, feature in enumerate(features, start=1):
+                for i, feature in branch_features.items():
                     if feature == 'v':
                         get_interval_solutions = self.get_interval_voltages
                         get_envelope = self.get_envelope_voltages
@@ -681,8 +747,16 @@ class TransientEFMSimulation:
                         get_interval_solutions = self.get_interval_power
                         get_envelope = self.get_envelope_power
                         get_interpolation = self.get_interpolated_power
+                    elif feature == 'c':
+                        if not isinstance(branch, SwitchBranch):
+                            continue
+
+                        get_interval_solutions = lambda branch: [[1 if s else 0 for s in interval]
+                                                                 for interval in self.get_interval_switch_states(branch)]
+                        get_envelope = None
+                        get_interpolation = None
                     else:
-                        raise ValueError(f'invalid feature: {feature}')
+                        raise AssertionError
 
                     fig.append_trace(
                         Scatter(
@@ -698,49 +772,61 @@ class TransientEFMSimulation:
                         col=1,
                     )
 
-                    fig.append_trace(
-                        Scatter(
-                            x=self.get_envelope_timesteps(),
-                            y=get_envelope(branch),
-                            legendgroup=f'{str(component)} (envelope)',
-                            name=f'{str(branch)} (envelope)',
-                            mode='lines',
-                            line={'color': color, 'dash': 'dash'},
-                            showlegend=showlegend,
-                        ),
-                        row=i,
-                        col=1,
-                    )
+                    if get_envelope is not None:
+                        fig.append_trace(
+                            Scatter(
+                                x=self.get_envelope_timesteps(),
+                                y=get_envelope(branch),
+                                legendgroup=f'{str(component)} (envelope)',
+                                name=f'{str(branch)} (envelope)',
+                                mode='lines',
+                                line={'color': color, 'dash': 'dash'},
+                                showlegend=showlegend,
+                            ),
+                            row=i,
+                            col=1,
+                        )
 
-                    ts, interpolated_solutions = get_interpolation(branch)
+                    if get_interpolation is not None:
+                        ts, interpolated_solutions = get_interpolation(branch)
 
-                    fig.append_trace(
-                        Scatter(
-                            x=ts,
-                            y=interpolated_solutions,
-                            legendgroup=f'{str(component)} (interpolated)',
-                            name=f'{str(branch)} (interpolated)',
-                            mode='lines',
-                            line={'color': color, 'dash': 'dot', 'width': 0.85},
-                            showlegend=showlegend,
-                            visible='legendonly',
-                        ),
-                        row=i,
-                        col=1,
-                    )
+                        fig.append_trace(
+                            Scatter(
+                                x=ts,
+                                y=interpolated_solutions,
+                                legendgroup=f'{str(component)} (interpolated)',
+                                name=f'{str(branch)} (interpolated)',
+                                mode='lines',
+                                line={'color': color, 'dash': 'dot', 'width': 0.85},
+                                showlegend=showlegend,
+                                visible='legendonly',
+                            ),
+                            row=i,
+                            col=1,
+                        )
 
                     showlegend = False
 
         # Update xaxis properties
-        for i, feature in enumerate(features, start=1):
-            if feature == 'v':
-                title_text = 'voltage V [V]'
-            elif feature == 'i':
-                title_text = 'current I [A]'
-            else:  # --> feature == 'p'
-                title_text = 'power P [W]'
+        axis_labels = {
+            'v': 'voltage V [V]',
+            'i': 'current I [A]',
+            'p': 'power P [W]',
+            's': 'state',
+            'c': 'switch state',
+        }
 
-            fig.update_yaxes(row=i, col=1, title_text=title_text)
+        for i, feature in enumerate(features, start=1):
+            fig.update_yaxes(row=i, col=1, title_text=axis_labels[feature])
+
+            if feature == 'c':
+                fig.update_yaxes(
+                    row=i,
+                    col=1,
+                    tickmode='array',
+                    tickvals=[0, 1],
+                    ticktext=['off', 'on'],
+                )
 
         fig.update_xaxes(row=len(features), col=1, title_text="time t [s]")
         fig.update_layout(title="Transient EFM Simulation Results")
