@@ -12,6 +12,12 @@ def yield_thread():
 
 
 def prefer_thread_yield(time: float = 0.01):
+    """
+    Requests to yield from current thread if runtime exceeds a certain amount of time.
+
+    :param time:
+        Time in seconds.
+    """
     thread = current_thread()
     tm = thread_time()
     if hasattr(thread, '_last_threadtime_stamp'):
